@@ -8,14 +8,21 @@ import jsii
 import publication
 import typing_extensions
 
+import aws_cdk.aws_cloudwatch._jsii
+import aws_cdk.aws_ec2._jsii
+import aws_cdk.aws_iam._jsii
+import aws_cdk.aws_kms._jsii
+import aws_cdk.aws_logs._jsii
+import aws_cdk.aws_secretsmanager._jsii
 import aws_cdk.core._jsii
+import aws_cdk.custom_resources._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/aws-elasticsearch",
-    "1.64.1",
+    "1.65.0",
     __name__[0:-6],
-    "aws-elasticsearch@1.64.1.jsii.tgz",
+    "aws-elasticsearch@1.65.0.jsii.tgz",
 )
 
 __all__ = [
